@@ -330,6 +330,19 @@ class ArgparseBuilder:
             advanced=True,
             argtype="filename",
         )
+        self.add_argument(
+            parser,
+            "--numbers_handling",
+            default="default",
+            choices=["default", "all", "none"],
+            help="question numbers handling strategy. "
+            "Default preserves zero questions and numbering "
+            "if the first question has number > 1, omits number otherwise. "
+            "All preserves all numbers, none omits all numbers "
+            "(was default behaviour pre-0.8.0.)",
+            advanced=True,
+            caption="Стратегия обработки номеров вопросов",
+        )
         self.add_argument(
             parser,
             "-v",
@@ -394,19 +407,6 @@ class ArgparseBuilder:
             advanced=True,
             caption="Стратегия обработки ссылок",
         )
-        self.add_argument(
-            cmdparse,
-            "--numbers_handling",
-            default="default",
-            choices=["default", "all", "none"],
-            help="question numbers handling strategy. "
-            "Default preserves zero questions and numbering "
-            "if the first question has number > 1, omits number otherwise. "
-            "All preserves all numbers, none omits all numbers "
-            "(was default behaviour pre-0.8.0.)",
-            advanced=True,
-            caption="Стратегия обработки номеров вопросов",
-        )
         self.add_argument(
             cmdparse,
             "--fix_spans",
@@ -418,8 +418,9 @@ class ArgparseBuilder:
         )
         self.add_argument(
             cmdparse,
-            "--bs_prettify",
-            action="store_true",
+            "--parsing_engine",
+            choices=["pypandoc", "bs_prettify", "bs_hard_unwrap", "bs"],
+            default="pypandoc",
             help="old html processing behaviour (before v0.5.5). "
             "Sometimes it will yield better results than the new default.",
             advanced=True,
@@ -665,6 +666,91 @@ class ArgparseBuilder:
             caption="Файл конфигурации",
             argtype="filename",
         )
+        cmdcompose_telegram = cmdcompose_filetype.add_parser("telegram")
+        self.add_argument(
+            cmdcompose_telegram,
+            "filename",
+            nargs="*",
+            help="file(s) to compose from.",
+            caption="Имя 4s-файла",
+            filetypes=[("chgksuite markup files", "*.4s")],
+        )
+        self.add_argument(
+            cmdcompose_telegram,
+            "--tgaccount",
+            default="my_account",
+            help="a made-up string designating account to use.",
+            caption="Аккаунт для постинга",
+        )
+        self.add_argument(
+            cmdcompose_telegram,
+            "--tgchannel",
+            required=True,
+            help="a channel to post questions to.",
+            caption="Название канала, в который постим"
+        )
+        self.add_argument(
+            cmdcompose_telegram,
+            "--tgchat",
+            required=True,
+            help="a chat connected to the channel.",
+            caption="Название чата, привязанного к каналу"
+        )
+        self.add_argument(
+            cmdcompose_telegram,
+            "--dry_run",
+            advanced=True,
+            action="store_true",
+            help="don't try to post.",
+            caption="Тестовый прогон (не постить в телеграм, только подключиться)"
+        )
+        self.add_argument(
+            cmdcompose_telegram,
+            "--nospoilers",
+            "-n",
+            action="store_true",
+            help="do not whiten (spoiler) answers.",
+            caption="Не закрывать ответы спойлером",
+        )
+        self.add_argument(
+            cmdcompose_telegram,
+            "--skip_until",
+            type=int,
+            help="skip questions until N.",
+            caption="Пропустить вопросы до N-го",
+        )
+        cmdcompose_add_stats = cmdcompose_filetype.add_parser("add_stats")
+        self.add_argument(
+            cmdcompose_add_stats,
+            "filename",
+            nargs="*",
+            help="file(s) to compose from.",
+            caption="Имя 4s-файла",
+            filetypes=[("chgksuite markup files", "*.4s")],
+        )
+        self.add_argument(
+            cmdcompose_add_stats,
+            "--rating_ids",
+            "-r",
+            help="tournament id (comma-separated in case of sync+async parts).",
+            caption="id турнира (через запятую для синхрона+асинхрона)",
+        )
+        self.add_argument(
+            cmdcompose_add_stats,
+            "--question_range",
+            help="range of question numbers to include.",
+            caption="Диапазон вопросов (например, \"25-36\"), по умолчанию берутся все)",
+        )
+        self.add_argument(
+            cmdcompose_add_stats,
+            "--team_naming_threshold",
+            "-tnt",
+            type=int,
+            default=2,
+            help="threshold for naming teams who scored at the question.",
+            caption="Граница вывода названий команд",
+        )
+
 
         cmdtrello = subparsers.add_parser("trello")
         cmdtrello_subcommands = cmdtrello.add_subparsers(dest="trellosubcommand")
